"""Auto-generated file, do not edit by hand. SN metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_SN = PhoneMetadata(id='SN', country_code=221, international_prefix='00',
    general_desc=PhoneNumberDesc(national_number_pattern='(?:[378]\\d{4}|93330)\\d{4}', possible_length=(9,)),
    fixed_line=PhoneNumberDesc(national_number_pattern='3(?:0(?:1[0-2]|80)|282|3(?:8[1-9]|9[3-9])|611)\\d{5}', example_number='301012345', possible_length=(9,)),
    mobile=PhoneNumberDesc(national_number_pattern='7(?:[06-8]\\d|21|90)\\d{6}', example_number='701234567', possible_length=(9,)),
    toll_free=PhoneNumberDesc(national_number_pattern='800\\d{6}', example_number='800123456', possible_length=(9,)),
    premium_rate=PhoneNumberDesc(national_number_pattern='88[4689]\\d{6}', example_number='884123456', possible_length=(9,)),
    shared_cost=PhoneNumberDesc(national_number_pattern='81[02468]\\d{6}', example_number='810123456', possible_length=(9,)),
    voip=PhoneNumberDesc(national_number_pattern='(?:3(?:392|9[01]\\d)\\d|93330)\\d{4}', example_number='933301234', possible_length=(9,)),
    number_format=[NumberFormat(pattern='(\\d{2})(\\d{3})(\\d{2})(\\d{2})', format='\\1 \\2 \\3 \\4', leading_digits_pattern=['[379]']),
        NumberFormat(pattern='(\\d{3})(\\d{2})(\\d{2})(\\d{2})', format='\\1 \\2 \\3 \\4', leading_digits_pattern=['8'])])



"""Auto-generated file, do not edit by hand. FO metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_FO = PhoneMetadata(id='FO', country_code=None, international_prefix=None,
    general_desc=PhoneNumberDesc(national_number_pattern='1\\d{2,3}', possible_length=(3, 4)),
    toll_free=PhoneNumberDesc(national_number_pattern='11[24]', example_number='112', possible_length=(3,)),
    emergency=PhoneNumberDesc(national_number_pattern='11[24]', example_number='112', possible_length=(3,)),
    short_code=PhoneNumberDesc(national_number_pattern='1(?:1[248]|(?:4[124]|71|8[7-9])\\d)', example_number='112', possible_length=(3, 4)),
    short_data=True)



"""Auto-generated file, do not edit by hand. ER metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_ER = PhoneMetadata(id='ER', country_code=None, international_prefix=None,
    general_desc=PhoneNumberDesc(national_number_pattern='[12]\\d\\d(?:\\d{3})?', possible_length=(3, 6)),
    toll_free=PhoneNumberDesc(national_number_pattern='1(?:1[2-46]|2[47]\\d{3})|20[12]\\d{3}', example_number='112', possible_length=(3, 6)),
    emergency=PhoneNumberDesc(national_number_pattern='1(?:1[2-46]|2[47]\\d{3})|20[12]\\d{3}', example_number='112', possible_length=(3, 6)),
    short_code=PhoneNumberDesc(national_number_pattern='1(?:1[2-6]|2(?:4422|7799))|20(?:1(?:606|917)|2(?:099|914))', example_number='112', possible_length=(3, 6)),
    short_data=True)



"""Auto-generated file, do not edit by hand. FM metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_FM = PhoneMetadata(id='FM', country_code=None, international_prefix=None,
    general_desc=PhoneNumberDesc(national_number_pattern='[39]\\d\\d(?:\\d{3})?', possible_length=(3, 6)),
    toll_free=PhoneNumberDesc(national_number_pattern='320\\d{3}|911', example_number='911', possible_length=(3, 6)),
    emergency=PhoneNumberDesc(national_number_pattern='320\\d{3}|911', example_number='911', possible_length=(3, 6)),
    short_code=PhoneNumberDesc(national_number_pattern='(?:32022|91)1', example_number='911', possible_length=(3, 6)),
    short_data=True)



"""Auto-generated file, do not edit by hand. TZ metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_TZ = PhoneMetadata(id='TZ', country_code=255, international_prefix='00[056]',
    general_desc=PhoneNumberDesc(national_number_pattern='(?:[26-8]\\d|41|90)\\d{7}', possible_length=(9,)),
    fixed_line=PhoneNumberDesc(national_number_pattern='2[2-8]\\d{7}', example_number='222345678', possible_length=(9,)),
    mobile=PhoneNumberDesc(national_number_pattern='(?:6[2-9]|7[13-9])\\d{7}', example_number='621234567', possible_length=(9,)),
    toll_free=PhoneNumberDesc(national_number_pattern='80[08]\\d{6}', example_number='800123456', possible_length=(9,)),
    premium_rate=PhoneNumberDesc(national_number_pattern='90\\d{7}', example_number='900123456', possible_length=(9,)),
    shared_cost=PhoneNumberDesc(national_number_pattern='8(?:40|6[01])\\d{6}', example_number='840123456', possible_length=(9,)),
    voip=PhoneNumberDesc(national_number_pattern='41\\d{7}', example_number='412345678', possible_length=(9,)),
    no_international_dialling=PhoneNumberDesc(national_number_pattern='(?:8(?:[04]0|6[01])|90\\d)\\d{6}', possible_length=(9,)),
    national_prefix='0',
    national_prefix_for_parsing='0',
    number_format=[NumberFormat(pattern='(\\d{2})(\\d{3})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['[24]'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{3})(\\d{3})(\\d{3})', format='\\1 \\2 \\3', leading_digits_pattern=['[67]'], national_prefix_formatting_rule='0\\1'),
        NumberFormat(pattern='(\\d{3})(\\d{2})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['[89]'], national_prefix_formatting_rule='0\\1')])



print("import: 'phonenumbers'")
import phonenumbers

print("import: 'phonenumbers.carrierdata'")
import phonenumbers.carrierdata

print("import: 'phonenumbers.data'")
import phonenumbers.data

print("import: 'phonenumbers.geodata'")
import phonenumbers.geodata

print("import: 'phonenumbers.shortdata'")
import phonenumbers.shortdata

print("import: 'phonenumbers.tzdata'")
import phonenumbers.tzdata




"""Auto-generated file, do not edit by hand. WF metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_WF = PhoneMetadata(id='WF', country_code=681, international_prefix='00',
    general_desc=PhoneNumberDesc(national_number_pattern='(?:[45]0|68|72|8\\d)\\d{4}', possible_length=(6,)),
    fixed_line=PhoneNumberDesc(national_number_pattern='(?:50|68|72)\\d{4}', example_number='501234', possible_length=(6,)),
    mobile=PhoneNumberDesc(national_number_pattern='(?:50|68|72|8[23])\\d{4}', example_number='501234', possible_length=(6,)),
    voicemail=PhoneNumberDesc(national_number_pattern='[48]0\\d{4}', example_number='401234', possible_length=(6,)),
    number_format=[NumberFormat(pattern='(\\d{2})(\\d{2})(\\d{2})', format='\\1 \\2 \\3', leading_digits_pattern=['[4-8]'])])



"""Auto-generated file, do not edit by hand. SH metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_SH = PhoneMetadata(id='SH', country_code=290, international_prefix='00',
    general_desc=PhoneNumberDesc(national_number_pattern='(?:[256]\\d|8)\\d{3}', possible_length=(4, 5)),
    fixed_line=PhoneNumberDesc(national_number_pattern='2(?:[0-57-9]\\d|6[4-9])\\d\\d', example_number='22158', possible_length=(4, 5)),
    mobile=PhoneNumberDesc(national_number_pattern='[56]\\d{4}', example_number='51234', possible_length=(5,)),
    voip=PhoneNumberDesc(national_number_pattern='262\\d\\d', example_number='26212', possible_length=(5,)),
    main_country_for_code=True,
    leading_digits='[256]')



"""Auto-generated file, do not edit by hand. 883 metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_883 = PhoneMetadata(id='001', country_code=883, international_prefix=None,
    general_desc=PhoneNumberDesc(national_number_pattern='51\\d{7}(?:\\d{3})?', possible_length=(9, 12)),
    voip=PhoneNumberDesc(national_number_pattern='51[013]0\\d{8}|5100\\d{5}', example_number='510012345', possible_length=(9, 12)),
    number_format=[NumberFormat(pattern='(\\d{3})(\\d{3})(\\d{3})', format='\\1 \\2 \\3', leading_digits_pattern=['510']),
        NumberFormat(pattern='(\\d{3})(\\d{3})(\\d{3})(\\d{3})', format='\\1 \\2 \\3 \\4', leading_digits_pattern=['510']),
        NumberFormat(pattern='(\\d{4})(\\d{4})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['5'])])



"""Auto-generated file, do not edit by hand. CF metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_CF = PhoneMetadata(id='CF', country_code=None, international_prefix=None,
    general_desc=PhoneNumberDesc(national_number_pattern='1\\d{2,3}', possible_length=(3, 4)),
    toll_free=PhoneNumberDesc(national_number_pattern='1(?:1[78]|22\\d)', example_number='117', possible_length=(3, 4)),
    emergency=PhoneNumberDesc(national_number_pattern='1(?:1[78]|22\\d)', example_number='117', possible_length=(3, 4)),
    short_code=PhoneNumberDesc(national_number_pattern='1(?:1[478]|220)', example_number='114', possible_length=(3, 4)),
    short_data=True)



"""Auto-generated file, do not edit by hand. CC metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_CC = PhoneMetadata(id='CC', country_code=61, international_prefix='001[14-689]|14(?:1[14]|34|4[17]|[56]6|7[47]|88)0011',
    general_desc=PhoneNumberDesc(national_number_pattern='1\\d{5,9}|(?:[48]\\d\\d|550)\\d{6}', possible_length=(6, 7, 8, 9, 10), possible_length_local_only=(8,)),
    fixed_line=PhoneNumberDesc(national_number_pattern='8(?:51(?:0(?:02|31|60)|118)|91(?:0(?:1[0-2]|29)|1(?:[28]2|50|79)|2(?:10|64)|3(?:[06]8|22)|4[29]8|62\\d|70[23]|959))\\d{3}', example_number='891621234', possible_length=(9,), possible_length_local_only=(8,)),
    mobile=PhoneNumberDesc(national_number_pattern='4(?:[0-3]\\d|4[047-9]|5[0-25-9]|6[6-9]|7[02-9]|8[0-2457-9]|9[017-9])\\d{6}', example_number='412345678', possible_length=(9,)),
    toll_free=PhoneNumberDesc(national_number_pattern='180(?:0\\d{3}|2)\\d{3}', example_number='1800123456', possible_length=(7, 10)),
    premium_rate=PhoneNumberDesc(national_number_pattern='190[0-26]\\d{6}', example_number='1900123456', possible_length=(10,)),
    shared_cost=PhoneNumberDesc(national_number_pattern='13(?:00\\d{3}|45[0-4])\\d{3}|13\\d{4}', example_number='1300123456', possible_length=(6, 8, 10)),
    voip=PhoneNumberDesc(national_number_pattern='(?:14(?:5\\d|71)|550\\d)\\d{5}', example_number='550123456', possible_length=(9,)),
    preferred_international_prefix='0011',
    national_prefix='0',
    national_prefix_for_parsing='0')
